==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/NPCWanderAroundFarGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal;

import cc.thonly.reverie_dreams.entity.npc.NPCEntityImpl;
import cc.thonly.reverie_dreams.entity.npc.NPCWorkModes;
import net.minecraft.class_1379;
import net.minecraft.class_243;
import net.minecraft.class_5534;
import org.jetbrains.annotations.Nullable;

public class NPCWanderAroundFarGoal extends class_1379 {
    public static final float CHANCE = 0.001f;
    private final NPCEntityImpl npcRole;
    protected final float probability;


    public NPCWanderAroundFarGoal(NPCEntityImpl pathAwareEntity, double d) {
        this(pathAwareEntity, d, CHANCE);
    }

    public NPCWanderAroundFarGoal(NPCEntityImpl mob, double speed, float probability) {
        super(mob, speed);
        this.npcRole = mob;
        this.probability = probability;
    }

    @Override
    public void method_6269() {
        if (this.npcRole.getWorkMode() == NPCWorkModes.PLAYING_MUSIC) {
            return;
        }
        super.method_6269();
    }

    @Override
    @Nullable
    protected class_243 method_6302() {
        if (this.field_6566.method_5799()) {
            class_243 vec3d = class_5534.method_31527(this.field_6566, 15, 7);
            return vec3d == null ? super.method_6302() : vec3d;
        }
        if (this.field_6566.method_59922().method_43057() >= this.probability) {
            return class_5534.method_31527(this.field_6566, 10, 7);
        }
        return super.method_6302();
    }

    @Override
    public boolean method_6264() {
        return this.field_6566.method_6065() == null && super.method_6264();
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/NPCWanderAroundFarGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal;

import cc.thonly.reverie_dreams.entity.npc.BaseNPCLikeEntity;
import cc.thonly.reverie_dreams.registry.content.NPCWorkModes;
import net.minecraft.class_1379;
import net.minecraft.class_243;
import net.minecraft.class_5534;
import org.jetbrains.annotations.Nullable;

public class NPCWanderAroundFarGoal extends class_1379 {
    public static final float CHANCE = 0.001f;
    private final BaseNPCLikeEntity npcRole;
    protected final float probability;


    public NPCWanderAroundFarGoal(BaseNPCLikeEntity pathAwareEntity, double d) {
        this(pathAwareEntity, d, CHANCE);
    }

    public NPCWanderAroundFarGoal(BaseNPCLikeEntity mob, double speed, float probability) {
        super(mob, speed);
        this.npcRole = mob;
        this.probability = probability;
    }

    @Override
    public void method_6269() {
        if (this.npcRole.getWorkMode() == NPCWorkModes.PLAYING_MUSIC) {
            return;
        }
        super.method_6269();
    }

    @Override
    @Nullable
    protected class_243 method_6302() {
        if (this.field_6566.method_5799()) {
            class_243 vec3d = class_5534.method_31527(this.field_6566, 15, 7);
            return vec3d == null ? super.method_6302() : vec3d;
        }
        if (this.field_6566.method_59922().method_43057() >= this.probability) {
            return class_5534.method_31527(this.field_6566, 10, 7);
        }
        return super.method_6302();
    }

    @Override
    public boolean method_6264() {
        return this.field_6566.method_6065() == null && super.method_6264();
    }
}
